function treatmatrix_switcher(action,handles)
%FUNCTION FOR PRETREATMENT OF MATRIX FOR COOR2DGUI
%
%   This function is used for pretreatment of data which are then used by
%   function corr2dgui. It asks user for name and indexes of spectra, then
%   cuts scale and creates one output matrix in a form which can be read by
%   corr2dgui.
%   It is able to read data from text files into an array, then it will
%   find a common scale and cuts data. Final result is saved into a file by
%   user's choice.
%
%   Copyright (c) by Tomas Pazderka
%   Revision: 0.1 Date: 4.12.2008

global input num numspec A B specmax specmin oper_data konst Xlim;

switch(action)
    case 'input'
        %Asking for users input...
        input = inputdlg({'Base name of spectra (with path and without numbered part)',...
            'First index of spectra','Last index of spectra','Incremental part of spectra',...
            'Form of numbering (x for one number, xx for two numbers and xxx for three numbers)',...
            'Suffix of the spectra (with leading dot)'},'Files for treatment',1,...
            {'/media/CORSAIR/_Data/Matlab/Dynamika_FTIR/NKRP1C','10','50','5','xx','_PWN.PRN'},'on');
        num = zeros(1,3);
        %Converting indexes into numbers
        for i=1:3
            num(i) = str2double(input(i+1));
        end
        numspec = (num(2)-num(1))/num(3)+1;
        
    case 'read'
        %Prealocation of cell array
        A = cell(1,numspec);
        %Reading user's files into a cell array
        for i=num(1):num(3):num(2)
            j = i/num(3)-num(1)/num(3)+1;
            k = num2str(i);
            switch size(cell2mat(input(5)),2)-size(k,2)
                case 0
                case 1
                    k = strcat('0',k);
                case 2
                    k = strcat('00',k);
                otherwise
                    errordlg('Size of entered strings is invalid!','Unknown size');
                    return
            end
            if exist(cell2mat(strcat(input(1),k,input(6))),'file') == 0
                errordlg('File not exist!','Bad file!');
                return
            else
                A{1,j} = importdata(cell2mat(strcat(input(1),k,input(6))));
            end
        end
        clear input num;
        set(handles.left,'Enable','on');
        set(handles.right,'Enable','on');
        
    case 'display'
        %Finding maximum and minimum for each data set
        m = size(A,2);
        specmin = -9999999;
        specmax = 9999999;
        for i=1:m
            if A{1,i}(1,1) > specmin;
                specmin = A{1,i}(1,1);
            end
            if A{1,i}(size(A{1,i},1),1) < specmax;
                specmax = A{1,i}(size(A{1,i},1),1);
            end
        end
        %Plotting the data set
        axes(handles.graf);
        Xlim(1) = round(specmin);
        Xlim(2) = round(specmax);
        color = {[0.8 0.8 0.8],[0.5 0 1],[1 0.5 0.15],[0.14 0.4 0.55],...
            [0.44 0.86 0.58],[0.42 0.26 0.15],[0.48 1 0],[1 0.08 0.58],...
            [1 0.73 0.06],'red','blue','green','yellow','black','cyan','magneta'};
        for i=1:m
            if i<16
                line(A{1,i}(:,1),A{1,i}(:,2),'LineWidth',1,'Color',color{i});
            else
                line(A{1,i}(:,1),A{1,i}(:,2),'LineWidth',1,'Color',color{i-15});
            end
        end
        set(handles.graf,'Xlim',Xlim);
        yminmax = get(gca,'YLim');
        %Creating a rectangle for selecting data range
        rectangle('Position',[specmin,yminmax(1,1),(specmax - specmin),...
            (yminmax(1,2) - yminmax(1,1))],'Tag','oper_vyber','EdgeColor',...
            'b','FaceColor',[0.92 0.92 0.92],'EraseMode','xor',...
            'ButtonDownFcn','treatmatrix_switcher rectangle');
        set(gcf,'Pointer','crosshair');
        set(gca,'DrawMode','fast');
        set(handles.left,'String',round(specmin));
        set(handles.right,'String',round(specmax));
        
    case 'cut'
        %Truncating the scale for equality through all data sets and interpolating
        %it by cubic spline
        specmin = round(specmin);
        specmax = round(specmax);
        if strcmp(get(get(handles.box,'SelectedObject'),'String'),'1 1/cm')
            xx = specmin:1:specmax;
        else
            xx = specmin:0.5:specmax;
        end
        B = xx';
        clear xx;
        for i=1:numspec
            k = 0;
            for j=1:size(A{1,i},1)
                if A{1,i}(j,1) < specmin || A{1,i}(j,1) > specmax
                else
                    k = k+1;
                    Data(k,:)=A{1,i}(j,:);
                end
            end
            yy = spline(Data(:,1),Data(:,2),B(:,1));
            B(:,i+1) = yy;
        end
        clear yy Data A;
        
    case 'save'
        %Saving output files by user's choice
        [FileName,PathName] = uiputfile({'*.txt','Text file (*.txt)'},...
                    'Save output (merged and truncated) spectra.');
        if isequal(FileName,0) || isequal(PathName,0)
            return;
        end
        save(fullfile(PathName,FileName),'B','-ascii');
        helpdlg('Data were succesfully saved onot disk.','Saved');




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% UNTESTED: REWRITE AND MAKE FIT INTO GUI co dela konst????
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

   
case 'rectangle'
   %Setting a rectangle to react on button press
   button = get(gcf,'SelectionType');
   if strcmp(button,'normal')  
      Hndl = findobj(gcbf,'Tag','oper_vyber');
      rectpos = get(Hndl,'Position');
      set(Hndl,'EdgeColor','r');
      pos = get(gca,'CurrentPoint');
      if pos(1,1) < (rectpos(1,1) + (rectpos(1,3)/20)),
         %Moving a left margin
         set(gcf,'WindowButtonMotionFcn','treatmatrix_switcher rectleft');
         waitforbuttonpress;
      elseif pos(1,1) > (rectpos(1,1) + rectpos(1,3) - (rectpos(1,3)/20)),
         %Moving a right margin
         set(gcf,'WindowButtonMotionFcn','treatmatrix_switcher rectright');
         waitforbuttonpress;
      else
         %Moving the whole rectangle
         konst = get(gca,'CurrentPoint');
         set(gcf,'WindowButtonMotionFcn','treatmatrix_switcher rectglob');
         waitforbuttonpress;
      end
   elseif strcmp(button,'extend')
      return;
   elseif strcmp(button,'alt')
      %odlozeni rectanglu
      Hndl = get(gcf,'CurrentObject');
      set(Hndl,'EdgeColor','b');
      set(gcf,'WindowButtonMotionFcn','');   
   else
      return;
   end   
   
case 'rectleft'
   %Moving a left margin
   pom = get(gca,'CurrentPoint');
   specmin = pom(1,1);
   Hndl = findobj(gcbf,'Tag','oper_vyber');
   rectpos = get(Hndl,'Position');
   sirka = rectpos(1,1) + rectpos(1,3) - specmin;
   if sirka <= 0
      return;
   end
   set(Hndl,'Position',[specmin,rectpos(1,2),sirka,rectpos(1,4)]);
   Hndl = findobj(gcbf,'Tag','Left');
   set(Hndl,'String',round(specmin));

case 'rectright'
   %Moving a right margin
   pom = get(gca,'CurrentPoint');
   specmax = pom(1,1);
   Hndl = findobj(gcbf,'Tag','oper_vyber');
   rectpos = get(Hndl,'Position');
   sirka = specmax - rectpos(1,1);
   if sirka <= 0
      return;
   end   
   set(Hndl,'Position',[rectpos(1,1),rectpos(1,2),sirka,rectpos(1,4)]);   
   Hndl = findobj(gcbf,'Tag','Right');
   set(Hndl,'String',round(specmax));      
   
case 'rectglob'   
   %Moving the whole rectangle
   pom = get(gca,'CurrentPoint');
   Hndl = findobj(gcbf,'Tag','oper_vyber');
   rectpos = get(Hndl,'Position');   
   specmin = rectpos(1,1) + pom(1,1) - konst(1,1);
   set(Hndl,'Position',[specmin,rectpos(1,2),rectpos(1,3),rectpos(1,4)]);   
   Hndl = findobj(gcbf,'Tag','Left');
   set(Hndl,'String',round(specmin));
   Hndl = findobj(gcbf,'Tag','Right');
   set(Hndl,'String',round((specmin + rectpos(1,3))));
   konst = pom(1,1);
      
case 'set'
   %nastaveni rectanglu na zaklade editu
   Hndl=findobj(gcbf,'Tag','Left');
   specmin = str2double(get(Hndl,'String'));
   Hndl=findobj(gcbf,'Tag','Right');
   specmax = str2double(get(Hndl,'String'));
   if (specmax > Xlim(2)) || (specmin < Xlim(1))
      errordlg('One of margins out of range!','Calculation Error');
      return;  
   elseif specmin > specmax
      errordlg('Left margin is grater than right margin!','Calculation Error');            
      return;
   end   
   Hndl = findobj(gcbf,'Tag','oper_vyber');
   rectpos = get(Hndl,'Position');   
   set(Hndl,'Position',[specmin,rectpos(1,2),(specmax - specmin),rectpos(1,4)]);
end
    